def sources():
    source = ["[***abuseipDB***](https://abuseipdb.com)","[***alienvault***](https://otx.alienvault.com)", "[***anubis***](https://jldc.me/anubis)", "[***bevigil****](https://bevigil.com/login)", "[***binaryedge****](https://binaryedge.io)", "[***bufferover****](https://tls.bufferover.run/)", "[***builtwith****](https://api.builtwith.com/domain-api)","[***c99****](https://subdomainfinder.c99.nl/)","[***censys****](https://censys.com/)", "[***certspotter****](https://sslmate.com/certspotter/)", "[***chaos****](https://chaos.projectdiscovery.io/)", "[**c*olumbusapi***](https://columbus.elmasy.com/)", "[***commoncrawl***](https://index.commoncrawl.org/)","[***crtsh***](https://crt.sh)", "[***cyfare***](https://cyfare.net)","[***digitorus***](https://www.digitorus.com/)", "[***dnsdumpster****](https://dnsdumpster.com/)", "[***dnsrepo***](https://dnsrepo.noc.org)", "[***fofa****](https://en.fofa.info/)","[***facebook****](https://developers.facebook.com/)", "[***fullhunt****](https://fullhunt.io/)", "[***google****](https://programmablesearchengine.google.com/controlpanel/create)","[***hackertarget***](https://hackertarget.com/)", "[***huntermap****](https://hunter.how/)", "[***intelx****](https://intelx.io/)", "[***leakix****](https://leakix.net/)", "[***merklemap***](https://www.merklemap.com)","[***myssl***](https://myssl.com)","[***netlas****](https://netlas.io/)","[***passivetotal****](https://api.riskiq.net/api/pdns_pt/#/)" ,"[***quake****](https://quake.360.cn/)", "[***racent***](https://face.racent.com)","[***rapidapi****](https://rapidapi.com/hub)", "[***rapiddns***](https://rapiddns.io/)","[***redhuntlabs****](https://devportal.redhuntlabs.com/)", "[***rsecloud****](https://rsecloud.com/search)","[***securitytrails****](http://securitytrails.com/)", "[***shodan****](https://shodan.io)", "[***shodanx***](https://github.com/RevoltSecurities/Shodanx)", "[***shrewdeye***](https://github.com/RevoltSecurities/Subdominator)", "[***sitedossier***](https://sitedossier.com/)", "[***subdomaincenter***](https://www.subdomain.center/)", "[***trickest****](https://trickest.io/)","[***urlscan***](https://urlscan.io/)", "[***virustotal****](https://virustotal.com/)", "[***waybackarchive***](https://archive.org/wayback)", "[***whoisxml****](https://whoisxmlapi.com)","[***zoomeyeapi****](https://docs.projectdiscovery.io/tools/subfinder/install#zoomeye-api)", "[***rapidfinder****](https://rapidapi.com/Glavier/api/subdomain-finder3/pricing): **Rapidfinder requires rapidapi api key but before it required to subscribe for free and please see here: https://rapidapi.com/Glavier/api/subdomain-finder3/pricing**", "[***rapidscan****](https://rapidapi.com/sedrakpc/api/subdomain-scan1/pricing): **Rapidscan requires rapidapi api key but before it required to subscribe for free and please see here: https://rapidapi.com/sedrakpc/api/subdomain-scan1/pricing**", "[***coderog****](https://rapidapi.com/coderog-coderog-default/api/subdomain-finder5/pricing): **Coderog source required to subscribe for free and please see here: https://rapidapi.com/coderog-coderog-default/api/subdomain-finder5/pricing**"]
    return source